import React from 'react';
import { storiesOf } from '@storybook/react';
import { action } from '@storybook/addon-actions';
import centered from '@storybook/addon-centered';
import { withKnobs, text, select, number, boolean } from '@storybook/addon-knobs';
import cssModule from '../src/styles';
import { AwesomeButtonProgress } from '../src/index';

storiesOf('AwesomeButtonProgress', module)
  .addDecorator(centered)
  .addDecorator(withKnobs)
  .add('Success', () => (
    <AwesomeButtonProgress
      size={select('Size', [null, 'small', 'medium', 'large'], 'large')}
      type={select('Type', ['primary', 'secondary', 'link'], 'primary')}
      disabled={boolean('Disabled', true)}
      cssModule={cssModule}
      action={(element, next) => {
        action('clicked');
        setTimeout(() => {
          next();
        }, 600);
      }}
    >
      {text('Text', 'Progress')}
    </AwesomeButtonProgress>
  ))
  .add('Custom Labels', () => (
    <AwesomeButtonProgress
      loadingLabel="Wait for it.."
      resultLabel="Done!"
      size={select('Size', [null, 'small', 'medium', 'large'], 'large')}
      type={select('Type', ['primary', 'secondary', 'link'], 'primary')}
      disabled={boolean('Disabled', true)}
      cssModule={cssModule}
      action={(element, next) => {
        action('clicked');
        setTimeout(() => {
          next();
        }, 600);
      }}
    >
      {text('Text', 'Progress')}
    </AwesomeButtonProgress>
  ))
  .add('Error Handling', () => (
    <AwesomeButtonProgress
      loadingLabel={text('loadingLabel', 'Wait for it..')}
      resultLabel={text('resultLabel', 'Done!')}
      releaseDelay={number('ReleaseDelay', 1000)}
      size={select('Size', [null, 'small', 'medium', 'large'], 'large')}
      type={select('Type', ['primary', 'secondary', 'link'], 'primary')}
      disabled={boolean('Disabled', false)}
      cssModule={cssModule}
      action={(element, next) => {
        setTimeout(() => {
          next(false, 'Error Message :(');
        }, 500);
      }}
    >
      {text('Text', 'Progress')}
    </AwesomeButtonProgress>
  ))
  .add('Disabled Button', () => (
    <AwesomeButtonProgress
      disabled={boolean('Disabled', true)}
      size={select('Size', [null, 'small', 'medium', 'large'], 'large')}
      type={select('Type', ['primary', 'secondary', 'link'], 'primary')}
      cssModule={cssModule}
      action={(element, next) => {
        action('clicked');
        setTimeout(() => {
          next();
        }, 600);
      }}
    >
      {text('Text', 'Progress')}
    </AwesomeButtonProgress>
  ));
